@@ -1,5 +1,6 @@
-#' Check if an object contains infinte values
+#' Check if an object contains infinite values
 #'
+#' @description
 #' Supported are atomic types (see \code{\link[base]{is.atomic}}), lists and data frames.
 #'
 #' @param x [\code{ANY}]\cr
@@ -13,5 +14,5 @@
 #' iris[3, 3] = Inf
 #' anyInfinite(iris)
 anyInfinite = function(x) {
-  .Call("c_any_infinite", x, PACKAGE = "checkmate")
+  .Call(c_any_infinite, x)
 }
