@@ -15,16 +15,14 @@
 #' @template tol
 #' @param add [\code{AssertCollection}]\cr
 #'  Collection to store assertions. See \code{\link{AssertCollection}}.
-#' @param .var.name [character(1)]\cr
-#'  Name for \code{x}. Defaults to a heuristic to determine
-#'  the name using \code{\link[base]{deparse}} and \code{\link[base]{substitute}}.
+#' @template var.name
 #' @return Converted \code{x}.
 #' @export
 #' @examples
 #' asInteger(c(1, 2, 3))
 #' asCount(1)
 #' asInt(1)
-asInteger = function(x, ..., tol = sqrt(.Machine$double.eps), add = NULL, .var.name) {
+asInteger = function(x, ..., tol = sqrt(.Machine$double.eps), add = NULL, .var.name = NULL) {
   assertIntegerish(x, ..., tol = tol, .var.name = vname(x, .var.name), add = NULL)
   storage.mode(x) = "integer"
   x
@@ -37,7 +35,7 @@ asInteger = function(x, ..., tol = sqrt(.Machine$double.eps), add = NULL, .var.n
 #' @param na.ok [\code{logical(1)}]\cr
 #'  Are missing values allowed? Default is \code{FALSE}.
 #' @export
-asCount = function(x, na.ok = FALSE, positive = FALSE, tol = sqrt(.Machine$double.eps), add = NULL, .var.name) {
+asCount = function(x, na.ok = FALSE, positive = FALSE, tol = sqrt(.Machine$double.eps), add = NULL, .var.name = NULL) {
   assertCount(x, na.ok, positive, tol, vname(x, .var.name), add = NULL)
   storage.mode(x) = "integer"
   x
@@ -46,7 +44,7 @@ asCount = function(x, na.ok = FALSE, positive = FALSE, tol = sqrt(.Machine$doubl
 #' @rdname asInteger
 #' @template bounds
 #' @export
-asInt = function(x, na.ok = FALSE, lower = -Inf, upper = Inf, tol = sqrt(.Machine$double.eps), add = NULL, .var.name) {
+asInt = function(x, na.ok = FALSE, lower = -Inf, upper = Inf, tol = sqrt(.Machine$double.eps), add = NULL, .var.name = NULL) {
   assertInt(x, na.ok, lower, upper, tol, vname(x, .var.name), add = NULL)
   storage.mode(x) = "integer"
   x
