@@ -13,7 +13,7 @@
 #' testDataFrame(iris, types = c("numeric", "factor"), min.rows = 1, col.names = "named")
 checkDataFrame = function(x, types = character(0L), any.missing = TRUE, all.missing = TRUE, min.rows = NULL, min.cols = NULL, nrows = NULL, ncols = NULL, row.names = NULL, col.names = NULL) {
   .Call(c_check_dataframe, x, any.missing, all.missing, min.rows, min.cols, nrows, ncols, row.names, col.names) %and%
-  checkListProps(x, types)
+  checkListTypes(x, types)
 }
 
 #' @export
