@@ -23,10 +23,10 @@
 #' testList(as.list(iris), types = c("numeric", "factor"))
 checkList = function(x, types = character(0L), any.missing = TRUE, all.missing = TRUE, len = NULL, min.len = NULL, max.len = NULL, unique = FALSE, names = NULL) {
   .Call(c_check_list, x, any.missing, all.missing, len, min.len, max.len, unique, names) %and%
-  checkListProps(x, types)
+  checkListTypes(x, types)
 }
 
-checkListProps = function(x, types = character(0L)) {
+checkListTypes = function(x, types = character(0L)) {
   if (length(types) == 0L)
     return(TRUE)
   qassert(types, "S")
