@@ -28,7 +28,7 @@ SEXP c_check_flag(SEXP, SEXP);
 SEXP c_check_count(SEXP, SEXP, SEXP, SEXP);
 SEXP c_check_int(SEXP, SEXP, SEXP, SEXP, SEXP);
 SEXP c_check_number(SEXP, SEXP, SEXP, SEXP, SEXP);
-SEXP c_check_string(SEXP, SEXP);
+SEXP c_check_string(SEXP, SEXP, SEXP);
 SEXP c_check_scalar(SEXP, SEXP);
 
 #endif
