@@ -1,6 +1,11 @@
 context("checkChoice")
 
 test_that("checkChoice", {
+  myobj = 1
+  expect_succ_all(Choice, myobj, 1:3)
+  myobj = 0
+  expect_fail_all(Choice, myobj, 1:3)
+
   expect_false(testChoice(character(0), letters))
   expect_false(testChoice(NULL, letters))
   expect_false(testChoice(1, NULL))
@@ -11,7 +16,6 @@ test_that("checkChoice", {
   expect_false(testChoice(NA_integer_, 1:10))
   expect_false(testChoice(1:2, 1:10))
 
-  expect_true(assertChoice(1L, 1:2))
   expect_error(assertChoice(-1, 1:2), "element of")
   expect_error(assertChoice(1L, list()), "atomic")
 })
